.. libpninexus Python bindings documentation master file, created by
   sphinx-quickstart on Tue Jul 28 15:12:05 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PNI/NeXus and h5cpp python bindings's documentation!
===============================================================

Contents:

.. toctree::
   :maxdepth: 2 

   installation
   users_guide
   api_guide
    


Welcome to the documentation of `python-pninexus`. This package is a python wrapper
for libh5cpp_ and libpninexus_.

.. _libh5cpp: https://github.com/ess-dmsc/h5cpp
.. _libpninexus: https://github.com/pni-libraries/libpninexus

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

